==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>تەكشۈرۈۋاتىدۇ، ھازىرلا تاماملىنىدۇ، سەۋىرچانلىق بىلەن ساقلىغىنىڭىزغا رەھمەت</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>تەييارلىنىۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>بەزى خاتالىقلار بايقالدى</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>ئۈستەليۈزىگە كىرىش</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>خۇش كەپسىز، سىستېما يېڭىلاندى</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>نۆۋەتتىكى نەشرى:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>كۈندىلىك خاتىرىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>يېڭىلاندى</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>كومپيۇتېرىڭىز قايتا قوزغىلىدۇ %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>كومپيۇتېرىڭىز تاقىلىدۇ %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>كۈندىلىك خاتىرىنى يىغىش</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>نامەلۇم خاتالىق</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>زاپاسلانمىدى</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>سىستېمىنى زاپاسلىغىلى بولمىدى، سىستېمىنى داۋاملىق يېڭىلىسىڭىز ئەسلىگە قايتۇرالمايسىز</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>دىسكا بوشلۇقى يېتەرسىز، دىسكىڭىزنى تازىلاپ ئاندىن يېڭىلاڭ</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>زاپاسلاش مۇلازىمىتىنى قوزغاتقىلى بولمىدى، تەكشۈرۈپ قايتا سىناڭ</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>يېڭىلاش مۇلازىمىتىنى قوزغاتقىلى بولمىدى، تەكشۈرۈپ قايتا سىناڭ</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>بېقىنىش خاتالىقى</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg خاتالىقى</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>قايتا زاپاسلاش</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>يېڭىلاشتىن چېكىنىش</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>داۋاملىق يېڭىلاش</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>ئۈستەليۈزىگە كىرىش</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>يېڭىلاشقا تەييارلىنىۋاتىدۇ...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>يېڭىلىغاندا كومپيۇتېرنى مەجبۇرىي تاقىۋەتمەڭ ياكى توكتىن ئۈزۈۋەتمەڭ، بولمىسا سىستېما بۇزۇلۇپ كېتىدۇ</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.35.tar.xz: BUILD/src/dde-update/translations/dde-update_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>تەكشۈرۈۋاتىدۇ، ھازىرلا تاماملىنىدۇ، سەۋىرچانلىق بىلەن ساقلىغىنىڭىزغا رەھمەت</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>تەييارلىنىۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>بەزى خاتالىقلار بايقالدى</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>ئۈستەليۈزىگە كىرىش</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>خۇش كەپسىز، سىستېما يېڭىلاندى</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>نۆۋەتتىكى نەشرى:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>يېڭىلاندى</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>كومپيۇتېرىڭىز قايتا قوزغىلىدۇ %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>كومپيۇتېرىڭىز تاقىلىدۇ %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>نامەلۇم خاتالىق</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>زاپاسلانمىدى</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>سىستېمىنى زاپاسلىغىلى بولمىدى، سىستېمىنى داۋاملىق يېڭىلىسىڭىز ئەسلىگە قايتۇرالمايسىز</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>دىسكا بوشلۇقى يېتەرسىز، دىسكىڭىزنى تازىلاپ ئاندىن يېڭىلاڭ</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>زاپاسلاش مۇلازىمىتىنى قوزغاتقىلى بولمىدى، تەكشۈرۈپ قايتا سىناڭ</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>يېڭىلاش مۇلازىمىتىنى قوزغاتقىلى بولمىدى، تەكشۈرۈپ قايتا سىناڭ</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>بېقىنىش خاتالىقى</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg خاتالىقى</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>قايتا زاپاسلاش</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>يېڭىلاشتىن چېكىنىش</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>داۋاملىق يېڭىلاش</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>ئۈستەليۈزىگە كىرىش</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>يېڭىلاشقا تەييارلىنىۋاتىدۇ...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>يېڭىلىغاندا كومپيۇتېرنى مەجبۇرىي تاقىۋەتمەڭ ياكى توكتىن ئۈزۈۋەتمەڭ، بولمىسا سىستېما بۇزۇلۇپ كېتىدۇ</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
